@@ -24,7 +24,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 	
 );
 
-$VERSION = '1.10';
+$VERSION = '1.7';
 
 use Carp;
 use strict;
@@ -158,13 +158,11 @@ sub _ParseXML {
       }
     }
     my $ixml = $innerxml;
-    while ($ixml =~ /^.*?\<${firsttag}(\>|\s[^\>]*\>)(.*?)$/) {
+    while ($ixml =~ /.*?\<${firsttag}(\>|\s[^\>]*\>)(.*?)$/) {
         $ixml = $2;
         $innerxml .= "</${firsttag}>";
-        if ($xmlfragment =~ /^(.*?)\<\/${firsttag}\>(.*)$/) {
-            my $ix = $1;
-            $innerxml .= $ix;
-            $ixml .= $ix; 
+        if ($xmlfragment =~ /(.*?)\<\/${firsttag}\>(.*)$/) {
+            $innerxml .= $1;
             $xmlfragment = $2;
         } else {
             die "Invalid XML";
@@ -226,9 +224,7 @@ sub _ParseXML {
             $ixml = $2;
             $innerxml .= "</${firsttag}>";
             if ($xmlfragment2 =~ /(.*?)\<\/${firsttag}\>(.*)$/) {
-                my $ix = $1;
-                $innerxml .= $ix;
-                $ixml .= $ix;
+                $innerxml .= $1;
                 $xmlfragment2 = $2;
             } else {
                 die "Invalid XML";
@@ -286,8 +282,7 @@ simpleXMLParse - Perl extension for pure perl XML parsing
 
 =head1 DESCRIPTION
 
-  simpleXMLParse currently does not handle CDATA. style is specified
-  as 1 or 2. 
+  simpleXMLParse currently handles everything except CDATA.
 
 =head2 EXPORT
 
